CryptException class
Exceção lançada quando a autenticação falha durante a decriptação.
Isso indica que os dados foram corrompidos ou adulterados, ou que a chave/nonce fornecidos estão incorretos.
- Implemented types
Constructors
- CryptException([String message = 'Autenticação falhou.'])
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited