AllValidationsGetMonth class

Catálogos públicos dos meses em português do Brasil.

Constructors

AllValidationsGetMonth()
Cria um acesso aos catálogos de meses por compatibilidade legada.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

listMonths → const List<String>
Meses de janeiro a dezembro.
mapMonths → const Map<String, int>
Associa cada nome de mês ao número de 1 a 12.