ValidationNotification class

Descreve uma falha de validação associada a uma propriedade.

Constructors

ValidationNotification({required String property, required String message})
Cria uma notificação para property com message.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Mensagem que explica a falha.
final
property String
Nome lógico da propriedade inválida.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converte a notificação para um mapa (JSON).
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited