BrDevelopmentFilter class

Registra todos os níveis em modo debug; em produção (dart --define) só registra BrLogLevel.warning e acima.

Use const bool.fromEnvironment('dart.vm.product') para detectar o modo.

Inheritance

Constructors

BrDevelopmentFilter({BrLogLevel minLevelProduction = BrLogLevel.warning})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
minLevelProduction BrLogLevel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldLog(BrLogRecord record) bool
Retorna true se o record deve ser encaminhado ao printer.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited