BrSimplePrinter class

Printer minimalista — uma única linha, sem cores.

Formato: [LEVEL] TAG: mensagem Com tempo: 2024-01-15 10:30:00.123 [LEVEL] TAG: mensagem

Ideal para outputs que não suportam ANSI (ex: arquivos de log, servidores CI).

Inheritance

Constructors

BrSimplePrinter({bool showTime = false, bool showTag = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTag bool
final
showTime bool
final

Methods

format(BrLogRecord record) List<String>
Formata record e retorna as linhas a serem escritas.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited