CestMask class
Formatter de campo para o código CEST (Código Especificador da Substituição Tributária).
Aplica a máscara 12.345.67 (7 dígitos): dois grupos separados por ..
Uso:
TextField(
keyboardType: TextInputType.number,
inputFormatters: [const CestMask()],
)
Exemplos de transformação:
'12'→'12''123'→'12.3''12345'→'12.345''1234567'→'12.345.67'
- Inheritance
-
- Object
- TextInputFormatter
- BrInputMask
- CestMask
Constructors
- CestMask()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
formatEditUpdate(
TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue -
Called when text is being typed or cut/copy/pasted in the EditableText.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited