ValidationNotifiable class
Acumula notificações produzidas por validações de contrato.
Constructors
- ValidationNotifiable()
- Cria uma instância sem notificações.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalid → bool
-
truequando existe ao menos uma notificação.no setter - isValid → bool
-
truequando nenhuma notificação foi adicionada.no setter -
notifications
→ List<
ValidationNotification> -
Lista mutável de notificações acumuladas.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addNotifications<
T> (T r) → void - Adiciona notificações a partir de formatos compatíveis.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printMessageErrors(
) → void - Imprime todas as mensagens de erro.
-
toResult<
T> (T value) → Result< List< ValidationNotification> , T> - Converte o estado de validação em um Result.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited