BrLogOutput class abstract
Recebe as linhas formatadas pelo BrLogPrinter e as escreve no destino.
Implemente esta classe para criar outputs customizados (arquivo, rede, etc.).
- Implementers
Constructors
- BrLogOutput()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Limpeza opcional (fecha arquivo, etc.).
-
init(
) → void - Inicialização opcional (abre arquivo, conecta socket, etc.).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
BrLogRecord record, List< String> lines) → void -
Escreve
linesno destino.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited