BrLogPrinter class abstract
Transforma um BrLogRecord em uma lista de linhas para o output.
Retorne múltiplas linhas quando a mensagem precisar de mais de uma linha (ex: pretty printer com header + body + stack trace).
- Implementers
Constructors
- BrLogPrinter()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
format(
BrLogRecord record) → List< String> -
Formata
recorde retorna as linhas a serem escritas. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited