BrMultiOutput class
Encaminha cada evento para múltiplos outputs simultaneamente.
BrMultiOutput([
BrDeveloperOutput(),
BrMemoryOutput(),
])
- Inheritance
-
- Object
- BrLogOutput
- BrMultiOutput
Constructors
-
BrMultiOutput(List<
BrLogOutput> outputs)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
outputs
→ List<
BrLogOutput> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
Limpeza opcional (fecha arquivo, etc.).
override
-
init(
) → void -
Inicialização opcional (abre arquivo, conecta socket, etc.).
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
BrLogRecord record, List< String> lines) → void -
Escreve
linesno destino.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited