BrPrettyPrinter class
Printer colorido com caixas delimitadoras.
Exemplo de output (terminal com suporte ANSI):
┌─────────────── Auth ───────────────
│ [INFO ] 10:30:00.123
│ login bem-sucedido
└────────────────────────────────────
- Inheritance
-
- Object
- BrLogPrinter
- BrPrettyPrinter
Constructors
- BrPrettyPrinter({bool showTime = true, bool showTag = true, bool useColors = true, int stackTraceMaxLines = 8})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showTag → bool
-
Exibe a tag do logger.
final
- showTime → bool
-
Exibe o horário do evento.
final
- stackTraceMaxLines → int
-
Número de linhas do stack trace a incluir (0 = todas).
final
- useColors → bool
-
Exibe as cores ANSI no terminal.
final
Methods
-
format(
BrLogRecord record) → List< String> -
Formata
recorde retorna as linhas a serem escritas.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited