PasswordPolicy class
Configuração de política de senha para isPassword.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minLength → int
-
final
- requireLowercase → bool
-
final
- requireNumber → bool
-
final
- requireSpecial → bool
-
final
- requireUppercase → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- medium → const PasswordPolicy
- Política média: maiúscula + minúscula + número, mínimo 6.
- strong → const PasswordPolicy
- Política forte (padrão): todos os requisitos, mínimo 8.
- weak → const PasswordPolicy
- Política fraca: apenas comprimento mínimo de 6.